The branch, master has been updated
       via  7e728c8 notifyd: Broadcast to all connected nodes
      from  099df25 source4 smbd: remove global control pipe from 
process_standard.

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 7e728c86c77d995809a68dfb26350052303ca122
Author: Amitay Isaacs <ami...@gmail.com>
Date:   Thu Sep 28 11:44:50 2017 +1000

    notifyd: Broadcast to all connected nodes
    
    CTDB_BROADCAST_VNNMAP includes only the nodes with lmaster roles.
    CTDB_BROADCAST_CONNECTED includes all the running nodes.
    
    Signed-off-by: Amitay Isaacs <ami...@gmail.com>
    Reviewed-by: Volker Lendecke <v...@samba.org>
    
    Autobuild-User(master): Amitay Isaacs <ami...@samba.org>
    Autobuild-Date(master): Fri Sep 29 08:38:10 CEST 2017 on sn-devel-144

-----------------------------------------------------------------------

Summary of changes:
 source3/smbd/notifyd/notifyd.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/smbd/notifyd/notifyd.c b/source3/smbd/notifyd/notifyd.c
index f645781..e4e5c78 100644
--- a/source3/smbd/notifyd/notifyd.c
+++ b/source3/smbd/notifyd/notifyd.c
@@ -81,7 +81,7 @@ struct notifyd_state {
         * broadcasts its messaging_reclog to every other notifyd in
         * the cluster. This is done by making ctdb send a message to
         * srvid CTDB_SRVID_SAMBA_NOTIFY_PROXY with destination node
         * number CTDB_BROADCAST_VNNMAP. Everybody in the cluster who
         * had called register_with_ctdbd this srvid will receive the
         * broadcasts.
         *
@@ -999,7 +999,7 @@ static void notifyd_broadcast_reclog(struct 
ctdbd_connection *ctdbd_conn,
                                  .iov_len = blob.length };
 
        ret = ctdbd_messaging_send_iov(
-               ctdbd_conn, CTDB_BROADCAST_VNNMAP,
+               ctdbd_conn, CTDB_BROADCAST_CONNECTED,
                CTDB_SRVID_SAMBA_NOTIFY_PROXY, iov, ARRAY_SIZE(iov));
        TALLOC_FREE(blob.data);
        if (ret != 0) {
@@ -81,7 +81,7 @@ struct notifyd_state {
         * the cluster. This is done by making ctdb send a message to
         * srvid CTDB_SRVID_SAMBA_NOTIFY_PROXY with destination node
-        * number CTDB_BROADCAST_VNNMAP. Everybody in the cluster who
+        * number CTDB_BROADCAST_CONNECTED. Everybody in the cluster who
         * had called register_with_ctdbd this srvid will receive the
         * broadcasts.


-- 
Samba Shared Repository

Reply via email to